@@ -485,4 +485,201 @@ TEST_DATA = {
             },
         },
     },
+    "verisoft": {
+        "ABMC1": {
+            "path": join(
+                DIRECTORIES["VERISOFT_EXAMPLES"],
+                "AMITA_Health",
+                "ANON0001.pdf",
+            ),
+            "data": {
+                "Patient Name": "ANON0001 F, H 600",
+                "Patient ID": "ANON0001 F, H 600",
+                "Institution": "ABMC",
+                "Physicist": "ME",
+                "Comment": "cGy/fx @ 100% IDL",
+                "Date": "2021-01-11 11:47:33",
+                "Version": "VeriSoft 6.2",
+                "Data Set A": "M:\\Eclipse Physics - Cancer Institute\\ABMC\\External Beam\\Point Dose QA\\RapidArc QA\\2021\\F, H\\Composite.dcm",
+                "Data Set B": "Data Set B\nAdded Data Sets:\nA.mcc\nB.mcc",
+                "Calibrate Air Density": "1.032",
+                "Gamma Dist.": "3.0mm",
+                "Gamma Dose": "3.0%",
+                "Gamma Dose Info": "Dose difference with ref. to max. dose of calculated volume",
+                "Threshold": "5.0%",
+                "Threshold Info": "of max. dose of calculated volume",
+                "Gamma (Min)": "0.001",
+                "Gamma (Mean)": "0.175",
+                "Gamma (Median)": "0.167",
+                "Gamma (Max)": "0.734",
+                "Gamma Min Position X": "100.0",
+                "Gamma Min Position Y": "20.0",
+                "Gamma Max Position X": "0.0",
+                "Gamma Max Position Y": "10.0",
+                "Gamma Min Position X Units": "mm",
+                "Gamma Min Position Y Units": "mm",
+                "Gamma Max Position X Units": "mm",
+                "Gamma Max Position Y Units": "mm",
+                "Abs Dose (Min)": "0.015",
+                "Abs Dose (Mean)": "3.854",
+                "Abs Dose (Median)": "2.316",
+                "Abs Dose (Max)": "60.338",
+                "Abs Dose (Min Units)": "cGy",
+                "Abs Dose (Mean Units)": "cGy",
+                "Abs Dose (Median Units)": "cGy",
+                "Abs Dose (Max Units)": "cGy",
+                "Abs Dose Min Position X": "100.0",
+                "Abs Dose Min Position Y": "20.0",
+                "Abs Dose Max Position X": "130.0",
+                "Abs Dose Max Position Y": "0.0",
+                "Abs Dose Min Position X Units": "mm",
+                "Abs Dose Min Position Y Units": "mm",
+                "Abs Dose Max Position X Units": "mm",
+                "Abs Dose Max Position Y Units": "mm",
+                "Number of Dose Points": "1,405",
+                "Evaluated Dose Points": "340",
+                "Evaluated Dose Points (%)": "24.2%",
+                "Passed Points": "340",
+                "Passed Points (%)": "100.0%",
+                "Failed Points": "0",
+                "Failed Points (%)": "0.0%",
+                "Pass Rate": "100.0",
+                "Pass Result Color": "Green",
+                "Passing Criteria": "Gamma ≤ 1.0",
+                "Passing Green": "93.0%",
+                "Passing Yellow": "90.0%",
+                "Passing Red": "0.0%",
+            },
+        },
+        "ABMC2": {
+            "path": join(
+                DIRECTORIES["VERISOFT_EXAMPLES"],
+                "AMITA_Health",
+                "ANON0002.pdf",
+            ),
+            "data": {
+                "Patient Name": "D, M",
+                "Patient ID": "ANON0002",
+                "Institution": "ABMC",
+                "Physicist": "JP",
+                "Comment": "200 cGy/fx @ 100% IDL",
+                "Date": "2021-01-15 12:56:44",
+                "Version": "VeriSoft 6.2",
+                "Data Set A": "M:\\Eclipse Physics - Cancer Institute\\ABMC\\External Beam\\Point Dose QA\\RapidArc QA\\2021\\D, M\\Composite.dcm",
+                "Data Set B": "Data Set B\nAdded Data Sets:\nA.mcc\nB.mcc",
+                "Calibrate Air Density": "1.040",
+                "Gamma Dist.": "3.0mm",
+                "Gamma Dose": "3.0%",
+                "Gamma Dose Info": "Dose difference with ref. to max. dose of selected slice",
+                "Threshold": "5.0%",
+                "Threshold Info": "of max. dose of selected slice",
+                "Gamma (Min)": "N/A",
+                "Gamma (Mean)": "N/A",
+                "Gamma (Median)": "N/A",
+                "Gamma (Max)": "N/A",
+                "Gamma Min Position X": "N/A",
+                "Gamma Min Position Y": "N/A",
+                "Gamma Max Position X": "N/A",
+                "Gamma Max Position Y": "N/A",
+                "Gamma Min Position X Units": "N/A",
+                "Gamma Min Position Y Units": "N/A",
+                "Gamma Max Position X Units": "N/A",
+                "Gamma Max Position Y Units": "N/A",
+                "Abs Dose (Min)": "N/A",
+                "Abs Dose (Mean)": "N/A",
+                "Abs Dose (Median)": "N/A",
+                "Abs Dose (Max)": "N/A",
+                "Abs Dose (Min Units)": "N/A",
+                "Abs Dose (Mean Units)": "N/A",
+                "Abs Dose (Median Units)": "N/A",
+                "Abs Dose (Max Units)": "N/A",
+                "Abs Dose Min Position X": "N/A",
+                "Abs Dose Min Position Y": "N/A",
+                "Abs Dose Max Position X": "N/A",
+                "Abs Dose Max Position Y": "N/A",
+                "Abs Dose Min Position X Units": "N/A",
+                "Abs Dose Min Position Y Units": "N/A",
+                "Abs Dose Max Position X Units": "N/A",
+                "Abs Dose Max Position Y Units": "N/A",
+                "Number of Dose Points": "1,405",
+                "Evaluated Dose Points": "891",
+                "Evaluated Dose Points (%)": "63.4%",
+                "Passed Points": "891",
+                "Passed Points (%)": "100.0%",
+                "Failed Points": "0",
+                "Failed Points (%)": "0.0%",
+                "Pass Rate": "100.0",
+                "Pass Result Color": "Green",
+                "Passing Criteria": "Gamma ≤ 1.0",
+                "Passing Green": "93.0%",
+                "Passing Yellow": "90.0%",
+                "Passing Red": "0.0%",
+            },
+        },
+        "ABMC3": {
+            "path": join(
+                DIRECTORIES["VERISOFT_EXAMPLES"],
+                "AMITA_Health",
+                "ANON0003.pdf",
+            ),
+            "data": {
+                "Patient Name": "C, R",
+                "Patient ID": "ANON0003",
+                "Institution": "ABMC",
+                "Physicist": "ME",
+                "Comment": "250 cGy/fx @ 100% IDL",
+                "Date": "2021-01-18 09:43:32",
+                "Version": "VeriSoft 6.2",
+                "Data Set A": "M:\\Eclipse Physics - Cancer Institute\\ABMC\\External Beam\\Point Dose QA\\RapidArc QA\\2021\\C, R\\Composite.dcm",
+                "Data Set B": "Data Set B\nAdded Data Sets:\nA.mcc\nB.mcc",
+                "Calibrate Air Density": "1.039",
+                "Gamma Dist.": "3.0mm",
+                "Gamma Dose": "3.0%",
+                "Gamma Dose Info": "Dose difference with ref. to max. dose of calculated volume",
+                "Threshold": "5.0%",
+                "Threshold Info": "of max. dose of calculated volume",
+                "Gamma (Min)": "0.000",
+                "Gamma (Mean)": "0.192",
+                "Gamma (Median)": "0.171",
+                "Gamma (Max)": "0.933",
+                "Gamma Min Position X": "90.0",
+                "Gamma Min Position Y": "30.0",
+                "Gamma Max Position X": "-10.0",
+                "Gamma Max Position Y": "20.0",
+                "Gamma Min Position X Units": "mm",
+                "Gamma Min Position Y Units": "mm",
+                "Gamma Max Position X Units": "mm",
+                "Gamma Max Position Y Units": "mm",
+                "Abs Dose (Min)": "0.001",
+                "Abs Dose (Mean)": "2.789",
+                "Abs Dose (Median)": "1.456",
+                "Abs Dose (Max)": "72.278",
+                "Abs Dose (Min Units)": "cGy",
+                "Abs Dose (Mean Units)": "cGy",
+                "Abs Dose (Median Units)": "cGy",
+                "Abs Dose (Max Units)": "cGy",
+                "Abs Dose Min Position X": "90.0",
+                "Abs Dose Min Position Y": "30.0",
+                "Abs Dose Max Position X": "130.0",
+                "Abs Dose Max Position Y": "20.0",
+                "Abs Dose Min Position X Units": "mm",
+                "Abs Dose Min Position Y Units": "mm",
+                "Abs Dose Max Position X Units": "mm",
+                "Abs Dose Max Position Y Units": "mm",
+                "Number of Dose Points": "1,405",
+                "Evaluated Dose Points": "668",
+                "Evaluated Dose Points (%)": "47.5%",
+                "Passed Points": "668",
+                "Passed Points (%)": "100.0%",
+                "Failed Points": "0",
+                "Failed Points (%)": "0.0%",
+                "Pass Rate": "100.0",
+                "Pass Result Color": "Green",
+                "Passing Criteria": "Gamma ≤ 1.0",
+                "Passing Green": "93.0%",
+                "Passing Yellow": "90.0%",
+                "Passing Red": "0.0%",
+            },
+        },
+    },
 }
