@@ -4,7 +4,7 @@
 # test_file_processor.py
 """unittest cases for file_processor."""
 #
-# Copyright (c) 2020 Dan Cutright
+# Copyright (c) 2021 Dan Cutright
 # This file is part of IQDM-PDF, released under a MIT license.
 #    See the file LICENSE included with this distribution, also
 
@@ -15,6 +15,16 @@ from IQDMPDF.paths import DIRECTORIES
 from os import listdir, unlink
 from os.path import join, isdir
 
+SIMPLE_PDF = join(DIRECTORIES["TEST_DATA"], "simple_test.pdf")
+
+
+def unlink_file(path):
+    """unlink may throw an error in GitHub WorkFlow"""
+    try:
+        unlink(path)
+    except Exception:
+        pass
+
 
 class TestFileProcessor(unittest.TestCase):
     """Unit tests for file_processor."""
@@ -32,7 +42,24 @@ class TestFileProcessor(unittest.TestCase):
         output_file = "test_process_file.txt"
         pdf_path = join(directory, file_path)
         file_processor.process_file(pdf_path, output_file, output_dir)
-        unlink(join(output_dir, "SNCPatient_" + output_file))
+        unlink_file(join(output_dir, "SNCPatient_" + output_file))
+
+    def test_process_file_worker(self):
+        directory = join(DIRECTORIES["SNCPATIENT_EXAMPLES"], "UChicago")
+        file_path = listdir(directory)[0]
+        pdf_path = join(directory, file_path)
+        data = file_processor.process_file_worker(pdf_path)
+        self.assertEqual(data["report_type"], "SNCPatient")
+
+        data = file_processor.process_file_worker(SIMPLE_PDF)
+        self.assertIsNone(data["report_type"])
+        self.assertIsNone(data["columns"])
+        self.assertIsNone(data["data"])
+
+        data = file_processor.process_file_worker("non_existent_file.pdf")
+        self.assertIsNone(data["report_type"])
+        self.assertIsNone(data["columns"])
+        self.assertIsNone(data["data"])
 
     def test_process_files(self):
         """Test process_files"""
@@ -41,34 +68,7 @@ class TestFileProcessor(unittest.TestCase):
         )
         test_files = [f for f in listdir() if f.endswith("_unittest.csv")]
         for file in test_files:
-            # Over-kill to compare data with a saved report? Requires
-            # maintenance everytime new examples are made, plus OS issues
-            # with file path names.
-
-            # with open(file, "r") as f:
-            #     test_data = f.read().split("\n")
-            #
-            #     # Overkill to compare data since each report type has its own
-            #     # tests? This causes file path issues between OSs
-            #     for r, row in enumerate(test_data[1:]):
-            #         test_data_split = csv_to_list(row)
-            #         # find file name relative to test_data dir
-            #         test_data_rel_path = get_relative_path(
-            #             test_data_split[-1], "test_data"
-            #         )
-            #         if test_data_rel_path is not None:
-            #             # find row of expected data with same relative path
-            #             for exp_r, exp_row in enumerate(self.csv_data[file][1:]):
-            #                 csv_data_split = csv_to_list(exp_row)
-            #                 csv_data_rel_path = get_relative_path(
-            #                     csv_data_split[-1], "test_data"
-            #                 )
-            #                 if test_data_rel_path == csv_data_rel_path:
-            #                     # csv_data and test_data rows have been matched
-            #                     for c, col in enumerate(test_data_split[:-1]):
-            #                         self.assertEqual(csv_data_split[c], col)
-
-            unlink(file)
+            unlink_file(file)
 
         # no recursive search
         directory = join(DIRECTORIES["SNCPATIENT_EXAMPLES"], "UChicago")
@@ -81,7 +81,7 @@ class TestFileProcessor(unittest.TestCase):
             if f.startswith("SNCPatient_results_") and f.endswith(".csv")
         ]
         for file in test_files:
-            unlink(file)
+            unlink_file(file)
 
     def mock_callback(self, msg):
         self.assertTrue("label" in msg.keys())
@@ -89,9 +89,21 @@ class TestFileProcessor(unittest.TestCase):
         self.assertTrue(isinstance(msg["label"], str))
         self.assertTrue(isinstance(msg["gauge"], float))
 
+    def test_process_files_multiprocessing(self):
+        """Test process_files with multiprocessing"""
+        file_processor.process_files(
+            DIRECTORIES["TEST_DATA"],
+            output_file="unittest.csv",
+            output_dir=".",
+            processes=4,
+        )
+        test_files = [f for f in listdir() if f.endswith("_unittest.csv")]
+        for file in test_files:
+            unlink(file)
+
     def test_process_files_raise_errors_kwarg(self):
         """Check that errors raised by process_file are addressed by kwarg"""
-        bad_dir = "this doesn't exist!#anywhee^&*)"
+        bad_dir = "thisDoesntExist"
         while isdir(bad_dir):
             bad_dir = bad_dir + "0"
 
